OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "Адресата на е-пошта не е правилно внесена",
    "%s has published the calendar »%s«" : "%s Објави календар »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Неочекувана грешка при испраќање на е-пошта. Контактирајте го администраторот.",
    "Successfully sent email to " : "Успешно испратена е-пошта до",
    "Hello," : "Здраво,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Сакаме да те информираме дека %s објави календар »%s«.",
    "Open »%s«" : "Отвори »%s«",
    "Cheers!" : "Поздрав!",
    "Calendar" : "Календар",
    "A Calendar app for Nextcloud" : "Календар апликација за Nextcloud",
    "Previous day" : "Предходен ден",
    "Previous week" : "Предходна недела",
    "Previous month" : "Предходен месец",
    "Next day" : "Следен ден",
    "Next week" : "Следна недела",
    "Next month" : "Следен месец",
    "+ New event" : "+ Нов настан",
    "Today" : "Денес",
    "Day" : "Ден",
    "Week" : "Недела",
    "Month" : "Месец",
    "Untitled calendar" : "Неименуван календар",
    "Edit name" : "Уреди име",
    "Saving name …" : "Зачувување име …",
    "Edit color" : "Уреди бои",
    "Saving color …" : "Зачувување боја …",
    "Copy private link" : "Копирај приватен линк",
    "Download" : "Превземи",
    "Unshare from me" : "Не споделувај со мене",
    "Delete" : "Избриши",
    "An error occurred, unable to change visibility of the calendar." : "Настана грешка, неможе да се промени видливоста на календарот.",
    "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
    "Calendar link copied to clipboard." : "Линк до календарот е копиран во клипборд.",
    "Calendar link could not be copied to clipboard." : "Линк до календарот неможе да се копира во клипборд.",
    "An error occurred, unable to rename the calendar." : "Настана грешка, неможе да се преименува календарот.",
    "An error occurred, unable to change the calendar's color." : "Настана грешка, неможе да се променат боите на календарот.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Одстранување на споделувањето на календарот за 1 секунда","Одстранување на споделувањето на календарот за {countdown} секунди"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Бришење на календарот за 1 секунда","Бришење на календарот за {countdown} секунди"],
    "Share link" : "Сподели линк",
    "Publish calendar" : "Објави календар",
    "Publishing calendar" : "Објавување на календар",
    "Copy public link" : "Копирај јавен линк",
    "Send link to calendar via email" : "Испрати линк до календарот преку е-пошта",
    "Enter one address" : "Внеси една адреса",
    "Sending email …" : "Испраќање е-пошта …",
    "Copy subscription link" : "Копирај линк за претплата",
    "Copying link …" : "Копирање линк …",
    "Copied link" : "Линкот е копиран",
    "Could not copy link" : "Неможе да се копира линкот",
    "Copy embedding code" : "Копирај код за вградување",
    "Copying code …" : "Копирање код …",
    "Copied code" : "Кодот е копиран",
    "Could not copy code" : "Неможе да се копира кодот",
    "Delete share link" : "Избриши го линкот за споделување",
    "Deleting share link …" : "Се брише линкот за споделување …",
    "An error occurred, unable to publish calendar." : "Настана грешка, неможе да се објави календарот.",
    "An error occurred, unable to send email." : "Настана грешка, неможе да се испрати е-пошта.",
    "Embed code copied to clipboard." : "Кодот за вградување е копиран во клипборд.",
    "Embed code could not be copied to clipboard." : "Кодот за вградување неможе да се копира во клипборд.",
    "Share with users or groups" : "Сподели со корисници или групи",
    "No users or groups" : "Нема корисници или групи",
    "can edit" : "може да се измени",
    "An error occurred, unable to change the permission of the share." : "Настана грешка, неможе да се променат дозволите за споделување.",
    "+ New calendar" : "+ Нов календар",
    "New calendar" : "Нов календар",
    "Creating calendar …" : "Креирање календар …",
    "New calendar with task list" : "Нов календар со листа на задачи",
    "An error occurred, unable to create the calendar." : "Настана грешка, неможе да се креира календар.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Внесете валиден линк (започнувајчи со http://, https://, webcal://, или webcals://)",
    "Import calendars" : "Увези календари",
    "Please select a calendar to import into …" : "Изберете календар за да направите увоз во него …",
    "Filename" : "Име на датотека",
    "Calendar to import into" : "Календар за да направите увоз во него",
    "Cancel" : "Откажи",
    "_Import calendar_::_Import calendars_" : ["Увези календар","Увези календари"],
    "Import partially failed. Imported {accepted} out of {total}." : "Увозот е делумно неуспешен. Увезени {accepted} од вкупно {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Успешно увезен %n настан","Успешно увезени %n настани."],
    "Automatic" : "Автоматски",
    "Automatic ({detected})" : "Автоматски ({detected})",
    "Enable birthday calendar" : "Овозможи календар со родендени",
    "Enable simplified editor" : "Овозможи поедноставен уредувач",
    "Show weekends" : "Прикажи викенди",
    "Show week numbers" : "Прикажи броеви на неделите",
    "Settings & import" : "Параметри & импорт",
    "before at" : "пред",
    "Notification" : "Известување",
    "Email" : "Е-пошта",
    "Audio notification" : "Аудио известување",
    "Other notification" : "Друго и звестување",
    "On date" : "На датум",
    "Edit time" : "Удери време",
    "Save time" : "Зачувај време",
    "Remove reminder" : "Одстрани потсетник",
    "on" : "на",
    "at" : "во",
    "+ Add reminder" : "+ Додади потсетник",
    "_second_::_seconds_" : ["секунда","секунди"],
    "_minute_::_minutes_" : ["минута","минути"],
    "_hour_::_hours_" : ["час","часа"],
    "_day_::_days_" : ["ден","дена"],
    "_week_::_weeks_" : ["недела","недели"],
    "No reminders yet" : "Сеуште нема потсетници",
    "Busy (tentative)" : "Зафатен (привремено)",
    "Busy" : "Зафатен",
    "Out of office" : "Надвор од канцеларија",
    "Unknown" : "Непознат",
    "{name} accepted your invitation." : "{name} ја прифати вашата покана.",
    "{name} accepted {organizerName}'s invitation." : "{name} ја прифати поканата од {organizerName}.",
    "{name} declined your invitation." : "{name} ја одби вашата покана.",
    "{name} declined {organizerName}'s invitation." : "{name} ја одби поканата од {organizerName}.",
    "{name} did not respond to your invitation yet." : "{name} сеуште нема одговорено на поканата.",
    "{name} did not respond to {organizerName}'s invitation yet." : "{name} сеуште нема одговорено на поканата од {organizerName}.",
    "Show busy times" : "Прикажи ги зафатените термини",
    "Send e-mail" : "Испрати пошта",
    "Chairperson" : "Претседател",
    "Required participant" : "Задолжителен учесник",
    "Remove attendee" : "Откажи присутност",
    "Search for e-mails, users, contacts, resources or rooms" : "Пребарувај за е-пошти, корисници, контакти, ресурси или соби",
    "No match found" : "Нема совпаѓања",
    "No attendees yet" : "Сè уште нема присутни",
    "(organizer)" : "(organizer)",
    "To send out invitations and handle responses,  [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
    "Event title" : "Наслов на настанот",
    "All day" : "Сите денови",
    "from {startDate}" : "од {startDate}",
    "from {startDate} at {startTime}" : "од {startDate} во {startTime}",
    "to {endDate}" : "до {endDate}",
    "to {endDate} at {endTime}" : "до {endDate} во {endTime}",
    "End repeat" : "Крај на повторувањето",
    "Select to end repeat" : "Избери крај на повторувањето",
    "never" : "никогаш",
    "on date" : "на датум",
    "after" : "после",
    "_time_::_times_" : ["еднаш","пати"],
    "first" : "прв",
    "third" : "трети",
    "fourth" : "четврти",
    "fifth" : "петти",
    "second to last" : "втор до последен",
    "last" : "последен",
    "Repeat" : "Повтори",
    "Repeat every" : "Повтори секој",
    "By day of the month" : "По ден во месецот",
    "On the" : "На",
    "_month_::_months_" : ["месец","месеци"],
    "_year_::_years_" : ["година","години"],
    "Monday" : "Понеделник",
    "weekday" : "недели",
    "Summary" : "Резиме",
    "More" : "Повеќе",
    "Save" : "Зачувај",
    "Update" : "Ажурирај",
    "Public calendar does not exist" : "Јавниот календар не постои",
    "Maybe the share was deleted or has expired?" : "Можеби споделувањето е избришано ики рокот му е поминат?",
    "Please select a timezone:" : "Изберете временска зона:",
    "Select Date" : "Избери датум",
    "from {formattedDate}" : "од {formattedDate}",
    "to {formattedDate}" : "до {formattedDate}",
    "on {formattedDate}" : "на {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "од {formattedDate} во {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "до {formattedDate} во {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "на {formattedDate} во {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} во {formattedTime}",
    "Please enter a valid date" : "Внесете валиден датум",
    "Please enter a valid date and time" : "Внесете валиден датум и време",
    "Type to search timezone" : "Пребарај временски зони",
    "Personal" : "Лично",
    "Delete this occurrence" : "Избришете ја оваа можност",
    "Delete this and all future" : "Избришете го овој и сете во иднина",
    "Details" : "Детали",
    "Attendees" : "Присутни",
    "Reminders" : "Потсетници",
    "Activity" : "Активност",
    "Projects" : "Проекти",
    "Show more details" : "Прикажи повече детали",
    "Close" : "Затвори",
    "Subscribe to {name}" : "Претплатете се на {name}",
    "Download {name}" : "Превземи {name}",
    "Anniversary" : "Годишнина",
    "Appointment" : "Назначување",
    "Business" : "Бизнис",
    "Education" : "Образование",
    "Holiday" : "Празник",
    "Meeting" : "Средба",
    "Miscellaneous" : "Разно",
    "Non-working hours" : "Неработни часови",
    "Not in office" : "Не во канцеларија",
    "Phone call" : "Телефонски повик",
    "Sick day" : "Болен ден",
    "Special occasion" : "Посебна пригода",
    "Travel" : "Патување",
    "Vacation" : "Одмор",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["Еден ден пред настанот во {formattedHourMinute}","%n дена пред настанот во {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["Една недела пред настанот во {formattedHourMinute}","%n недели пред настанот во {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "На денот на настанот во {formattedHourMinute}",
    "{time} before the event starts" : "{time} пред да започне настанот",
    "{time} before the event ends" : "{time} пред да заврши настанот",
    "{time} after the event starts" : "{time} откако ќе започне настанот",
    "{time} after the event ends" : "{time} одкако ќе заврши настанот",
    "on {time}" : "во {time}",
    "on {time} ({timezoneId})" : "во {time} ({timezoneId})",
    "Week {number} of {year}" : "{number} недела од {year}",
    "Does not repeat" : "Не повторувај",
    "Daily" : "Дневно",
    "Weekly" : "Неделно",
    "Monthly" : "Месечно",
    "Yearly" : "Годишно",
    "_Every %n day_::_Every %n days_" : ["Секој ден","Секој %n дена"],
    "_Every %n week_::_Every %n weeks_" : ["Секоја недела","Секој %n недели"],
    "_Every %n month_::_Every %n months_" : ["Секој месец","Секој %n месеци"],
    "_Every %n year_::_Every %n years_" : ["Секоја година","Секој %n години"],
    "_on {weekday}_::_on {weekdays}_" : ["во {weekday}","во {weekdays}"],
    "in {monthNames}" : "во {monthNames}",
    "until {untilDate}" : "до {untilDate}",
    "_%n time_::_%n times_" : ["уште еднаш","%n пати"],
    "_+%n more_::_+%n more_" : ["+%n друг","+%n други"],
    "Untitled event" : "Неименуван настан",
    "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
    "When shared show only busy" : "Кога е споделено покажи зафатен",
    "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар.",
    "Location" : "Локација",
    "Add a location" : "Додади локација",
    "Description" : "Опис",
    "Add a description" : "Додади опис",
    "Status" : "Статус",
    "Confirmed" : "Потврдено",
    "Tentative" : "Прелиминарен",
    "Cancelled" : "Откажано",
    "Confirmation about the overall status of the event." : "Потврда за целокупниот статус на настанот.",
    "Show as" : "Крикажи како",
    "Take this event into account when calculating free-busy information." : "Го има во предвид овој настан при пресметување на информации за слободен-зафатен.",
    "Free" : "Слободен",
    "Categories" : "Категории",
    "Categories help you to structure and organize your events." : "Категориите ви помагаат да ги структурирате и организирате вашите настани.",
    "Search or add categories" : "Барај или додади категории",
    "Add this as a new category" : "Додади како нова категорија",
    "Custom color" : "Прилагодена боја",
    "Imported {filename}" : "Импортирано {filename}",
    "Meditation" : "Медитација",
    "Relaxing" : "Релаксирање",
    "Relax" : "Опуштање",
    "Presentation" : "Презентација",
    "Present" : "Тековно",
    "Camping" : "Кампување",
    "Camp" : "Камп",
    "Movie" : "Филм",
    "Cinema" : "Кино",
    "Graduation" : "Дипломирање",
    "Brainstorm" : "Бура",
    "Baseball" : "Бејзбол",
    "Meet" : "Запознавање",
    "Planning" : "Планирање",
    "Office" : "Канцеларија",
    "Party" : "Забава",
    "Celebration" : "Прослава",
    "Mail" : "Електронска пошта",
    "Soccer" : "Фудбал",
    "Football" : "Фудбал",
    "Gaming" : "Играње",
    "Play" : "Слајдшоу",
    "Game" : "Игра",
    "Drive" : "Возење",
    "Bicycle" : "Велосипед",
    "Cycle" : "Циклус",
    "Biking" : "Велосипедизам",
    "Podcast" : "Подкаст",
    "Basketball" : "Кошарка",
    "Fishing" : "Риболов",
    "Hiking" : "Пешачење",
    "Hike" : "Пешачење",
    "Art" : "Уметност",
    "Exhibition" : "Изложба",
    "Museum" : "Музеј",
    "Pilates" : "Пилатес",
    "Park" : "Парк",
    "Studying" : "Учење",
    "Doctor" : "Доктор",
    "Health" : "Здравје",
    "Dentist" : "Заболекар",
    "Interview" : "Интервју",
    "Training" : "Тренинг",
    "Practice" : "Пракса",
    "Sports" : "Спорт",
    "Exercise" : "Вежба",
    "Work out" : "Работа",
    "Working out" : "Работење",
    "Barber" : "Бербер",
    "Haircut" : "Пострижување",
    "Exam" : "Испит",
    "Working" : "Работа",
    "New Years Eve" : "Новогодишна ноќ",
    "NYE" : "Нова година",
    "Fireworks" : "Огномет",
    "Running" : "Трчање",
    "Go for a run" : "Одење на трчање",
    "Marathon" : "Маратон",
    "Call" : "Повик",
    "Calling" : "Повикувајќи",
    "Christmas" : "Божиќ",
    "Conference" : "Конференција",
    "Pizza" : "Пица",
    "Travelling" : "Патување",
    "Journey" : "Патување",
    "Collaborate" : "Соработка",
    "Lecture" : "Читање",
    "Seminar" : "Семинар",
    "Photograph" : "Фотографија",
    "Celebrate" : "Прослава",
    "Shopping" : "Купување",
    "Skate" : "Скејтбординг",
    "Skateboard" : "Скејтбординг",
    "Wine tasting" : "Дегустација на вино",
    "Golf" : "Голф",
    "Dinner" : "Вечера",
    "Lunch" : "Ручек",
    "Global" : "Глобално"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
